/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.batch.planner.web.internal.portlet.action;

import com.liferay.batch.planner.constants.BatchPlannerPortletKeys;
import com.liferay.batch.planner.service.BatchPlannerPlanService;
import com.liferay.portal.kernel.portlet.bridges.mvc.BaseMVCActionCommand;
import com.liferay.portal.kernel.portlet.bridges.mvc.MVCActionCommand;
import com.liferay.portal.kernel.util.ParamUtil;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Matija Petanjek
 */
@Component(
	property = {
		"javax.portlet.name=" + BatchPlannerPortletKeys.BATCH_PLANNER,
		"mvc.command.name=/batch_planner/delete_batch_planner_plan_template"
	},
	service = MVCActionCommand.class
)
public class DeleteBatchPlannerPlanTemplateMVCActionCommand
	extends BaseMVCActionCommand {

	@Override
	protected void doProcessAction(
			ActionRequest actionRequest, ActionResponse actionResponse)
		throws Exception {

		long batchPlannerPlanId = ParamUtil.getLong(
			actionRequest, "batchPlannerPlanId");

		if (batchPlannerPlanId != 0) {
			_batchPlannerPlanService.deleteBatchPlannerPlan(batchPlannerPlanId);
		}
		else {
			_deleteBatchPlannerPlans(
				ParamUtil.getLongValues(actionRequest, "batchPlannerPlanIds"));
		}
	}

	private void _deleteBatchPlannerPlans(long[] batchPlannerPlanIds)
		throws Exception {

		for (long batchPlannerPlanId : batchPlannerPlanIds) {
			_batchPlannerPlanService.deleteBatchPlannerPlan(batchPlannerPlanId);
		}
	}

	@Reference
	private BatchPlannerPlanService _batchPlannerPlanService;

}